==> openjdk7-src-7.u95_2.6.4-1-armv7h.pkg.tar.xz: sun/java2d/cmm/PCMM.java <==
/*
 * Copyright (c) 2006, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package sun.java2d.cmm;

import java.awt.color.ICC_Profile;

/* Pluggable CMM interface */

public interface PCMM {

    /* methods invoked from ICC_Profile */
    public long loadProfile(byte[] data);
    public void freeProfile(long profileID);
    public int  getProfileSize(long profileID);
    public void getProfileData(long profileID, byte[] data);
    public void getTagData(long profileID, int tagSignature, byte[] data);
    public int getTagSize(long profileID, int tagSignature);
    public void setTagData(long profileID, int tagSignature, byte[] data);

    /* methods for creating ColorTransforms */
    public ColorTransform createTransform(ICC_Profile profile, int renderType,
                                          int transformType);

    public ColorTransform createTransform(ColorTransform[] transforms);
}

==> openjdk7-src-7.u151_2.6.11-1-armv7h.pkg.tar.xz: sun/java2d/cmm/PCMM.java <==
/*
 * Copyright (c) 2006, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package sun.java2d.cmm;

import java.awt.color.ICC_Profile;

/* Pluggable CMM interface */

public interface PCMM {

    /* methods invoked from ICC_Profile */
    public Profile loadProfile(byte[] data);
    public void freeProfile(Profile p);
    public int  getProfileSize(Profile p);
    public void getProfileData(Profile p, byte[] data);
    public void getTagData(Profile p, int tagSignature, byte[] data);
    public int getTagSize(Profile p, int tagSignature);
    public void setTagData(Profile p, int tagSignature, byte[] data);

    /* methods for creating ColorTransforms */
    public ColorTransform createTransform(ICC_Profile profile, int renderType,
                                          int transformType);

    public ColorTransform createTransform(ColorTransform[] transforms);
}
